You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by sc...@apache.org on 2016/06/30 08:16:56 UTC

maven-integration-testing git commit: o Updated to show the version the tests will be run with as early as possible.

Repository: maven-integration-testing
Updated Branches:
  refs/heads/master 206692894 -> faecb5dc5


o Updated to show the version the tests will be run with as early as possible.


Project: http://git-wip-us.apache.org/repos/asf/maven-integration-testing/repo
Commit: http://git-wip-us.apache.org/repos/asf/maven-integration-testing/commit/faecb5dc
Tree: http://git-wip-us.apache.org/repos/asf/maven-integration-testing/tree/faecb5dc
Diff: http://git-wip-us.apache.org/repos/asf/maven-integration-testing/diff/faecb5dc

Branch: refs/heads/master
Commit: faecb5dc54dfb65d84ff11011739307f3127358c
Parents: 2066928
Author: Christian Schulte <sc...@apache.org>
Authored: Thu Jun 30 10:15:35 2016 +0200
Committer: Christian Schulte <sc...@apache.org>
Committed: Thu Jun 30 10:15:35 2016 +0200

----------------------------------------------------------------------
 run-its.bat | 4 ++--
 run-its.sh  | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/maven-integration-testing/blob/faecb5dc/run-its.bat
----------------------------------------------------------------------
diff --git a/run-its.bat b/run-its.bat
index a738643..098ff3e 100644
--- a/run-its.bat
+++ b/run-its.bat
@@ -1,7 +1,7 @@
 @REM How JvZ runs the ITs from a clean slate if it would be on Windows
 
-mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%/repo 
+mvn clean install --show-version -Prun-its,embedded -Dmaven.repo.local=%cd%/repo 
 
 @REM If behind a proxy try this..
 
-@REM mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%/repo -Dproxy.active=true -Dproxy.type=http -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass=
+@REM mvn clean install --show-version -Prun-its,embedded -Dmaven.repo.local=%cd%/repo -Dproxy.active=true -Dproxy.type=http -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass=

http://git-wip-us.apache.org/repos/asf/maven-integration-testing/blob/faecb5dc/run-its.sh
----------------------------------------------------------------------
diff --git a/run-its.sh b/run-its.sh
index d251099..4c55242 100755
--- a/run-its.sh
+++ b/run-its.sh
@@ -21,8 +21,8 @@
 
 # How I run the ITs from a clean slate. Though I do this with a primed Nexus instance. JvZ.
 
-env LANG=C LC_ALL=C mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo
+env LANG=C LC_ALL=C mvn clean install --show-version -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo
 
 # If behind a proxy try this
 
 # env LANG=C LC_ALL=C mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo -Dproxy.active=true -Dproxy.type=http -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass=
@@ -21,8 +21,8 @@
 # If behind a proxy try this
 
-# env LANG=C LC_ALL=C mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo -Dproxy.active=true -Dproxy.type=http -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass=
+# env LANG=C LC_ALL=C mvn clean install --show-version -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo -Dproxy.active=true -Dproxy.type=http -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass=